Module edge

Module edge 

Bindings to the Edge Storage API.

Enums

Error
Errors that may occur while using the Edge Storage API.
StorageZone
Storage Zones with their own API endpoints.
UploadError
Errors that may occur when uploading files

Functions

upload_file_by_path
Upload a file to the given Storage Zone by local path.
upload_file_data
Upload bytes to the given Storage Zone.