pub struct Error<T>where
T: Error + 'static,{ /* private fields */ }Expand description
An error returned by an API call.
The error includes the HTTP Method and URL of the API call, regardless of whether the request was actually sent to the server.
Implementations
sourceimpl<T> Error<T>where
T: Error + 'static,
impl<T> Error<T>where
T: Error + 'static,
sourcepub fn map<F, U>(self, f: F) -> Error<U>where
F: FnOnce(T) -> U,
U: Error + 'static,
pub fn map<F, U>(self, f: F) -> Error<U>where
F: FnOnce(T) -> U,
U: Error + 'static,
Convert the contained T error, if present.
sourcepub fn method(&self) -> &Method
pub fn method(&self) -> &Method
Returns the HTTP Method of the failed request.
Note that the request may not have happened before the error occurred. In this case, this merely indicates what method the resulting API call would have used.