Bindings to the Edge Storage API.
Enums
- Error
- Errors that may occur while using the Edge Storage API.
- Storage
Zone - Storage Zones with their own API endpoints.
- Upload
Error - Errors that may occur when uploading files
Functions
- upload_
file_ by_ path - Upload a file to the given Storage Zone by local path.
- upload_
file_ data - Upload bytes to the given Storage Zone.