Bindings to the Edge Storage API.
Enums
Errors that may occur while using the Edge Storage API.
Storage Zones with their own API endpoints.
Errors that may occur when uploading files
Functions
Upload a file to the given Storage Zone by local path.
Upload bytes to the given Storage Zone.