pub struct Client(_);
API Client initialized with an API access key.

Implementations

Create a new Client using the given access key.

The client is configured to always use HTTPS.

Errors

See ClientError.

Methods from Deref<Target = Client>

Convenience method to make a GET request to a URL.

Errors

This method fails whenever the supplied Url cannot be parsed.

Convenience method to make a POST request to a URL.

Errors

This method fails whenever the supplied Url cannot be parsed.

Convenience method to make a PUT request to a URL.

Errors

This method fails whenever the supplied Url cannot be parsed.

Convenience method to make a PATCH request to a URL.

Errors

This method fails whenever the supplied Url cannot be parsed.

Convenience method to make a DELETE request to a URL.

Errors

This method fails whenever the supplied Url cannot be parsed.

Convenience method to make a HEAD request to a URL.

Errors

This method fails whenever the supplied Url cannot be parsed.

Start building a Request with the Method and Url.

Returns a RequestBuilder, which will allow setting headers and the request body before sending.

Errors

This method fails whenever the supplied Url cannot be parsed.

Executes a Request.

A Request can be built manually with Request::new() or obtained from a RequestBuilder with RequestBuilder::build().

You should prefer to use the RequestBuilder and RequestBuilder::send().

Errors

This method fails if there was an error while sending request, redirect loop was detected or redirect limit was exhausted.